==> aspose_words_cloud-20.10.1.tar.gz: lib/src/models/bookmarks_outline_level_data.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="bookmarks_outline_level_data.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// container class for individual bookmarks outline level.
class BookmarksOutlineLevelData implements ModelBase {
  /// Gets or sets specify the bookmark's level.
  int bookmarksOutlineLevel;

  /// Gets or sets specify the bookmark's name.
  String name;

  @override
  void deserialize(Map<String, dynamic> json) {
    if (json.containsKey('BookmarksOutlineLevel')) {
      this.bookmarksOutlineLevel = json['BookmarksOutlineLevel'];
    } else {
      this.bookmarksOutlineLevel = null;
    }

    if (json.containsKey('Name')) {
      this.name = json['Name'];
    } else {
      this.name = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = new Map<String, dynamic>();
    if (this.bookmarksOutlineLevel != null) {
      _result['BookmarksOutlineLevel'] = this.bookmarksOutlineLevel;
    }

    if (this.name != null) {
      _result['Name'] = this.name;
    }
    return _result;
  }
}

==> aspose_words_cloud-20.10.2.tar.gz: lib/src/models/bookmarks_outline_level_data.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="bookmarks_outline_level_data.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// container class for individual bookmarks outline level.
class BookmarksOutlineLevelData implements ModelBase {
  /// Gets or sets specify the bookmark's level.
  int bookmarksOutlineLevel;

  /// Gets or sets specify the bookmark's name.
  String name;

  @override
  void deserialize(Map<String, dynamic> json) {
    if (json.containsKey('BookmarksOutlineLevel')) {
      bookmarksOutlineLevel = json['BookmarksOutlineLevel'];
    } else {
      bookmarksOutlineLevel = null;
    }

    if (json.containsKey('Name')) {
      name = json['Name'];
    } else {
      name = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = <String, dynamic>{};
    if (bookmarksOutlineLevel != null) {
      _result['BookmarksOutlineLevel'] = bookmarksOutlineLevel;
    }

    if (name != null) {
      _result['Name'] = name;
    }
    return _result;
  }
}
